@@ -42,24 +42,6 @@ G_DEFINE_TYPE (ChamplainTile, champlain_tile, CLUTTER_TYPE_ACTOR)
   (G_TYPE_INSTANCE_GET_PRIVATE ((o), CHAMPLAIN_TYPE_TILE, ChamplainTilePrivate))
 
 
-static void paint (ClutterActor *self);
-static void pick (ClutterActor *self, 
-    const ClutterColor *color);
-static void get_preferred_width (ClutterActor *self,
-    gfloat for_height,
-    gfloat *min_width_p,
-    gfloat *natural_width_p);
-static void get_preferred_height (ClutterActor *self,
-    gfloat for_width,
-    gfloat *min_height_p,
-    gfloat *natural_height_p);
-static void allocate (ClutterActor *self,
-    const ClutterActorBox *box,
-    ClutterAllocationFlags flags);
-static void map (ClutterActor *self);
-static void unmap (ClutterActor *self);
-
-
 enum
 {
   PROP_0,
@@ -91,12 +73,13 @@ struct _ChamplainTilePrivate
 
   ChamplainState state; /* The tile state: loading, validation, done */
   /* The tile actor that will be displayed after champlain_tile_display_content () */
-  ClutterActor *content_actor; 
+  ClutterActor *content_actor;
   ClutterGroup *content_group; /* A group used for the fade in effect */
   gboolean fade_in;
 
   GTimeVal *modified_time; /* The last modified time of the cache */
   gchar *etag; /* The HTTP ETag sent by the server */
+  gboolean content_displayed;
 };
 
 static void
@@ -195,16 +178,110 @@ champlain_tile_set_property (GObject *object,
 }
 
 
+static void
+paint (ClutterActor *self)
+{
+  ChamplainTilePrivate *priv = GET_PRIVATE (self);
+
+  clutter_actor_paint (CLUTTER_ACTOR (priv->content_group));
+}
+
+
+static void
+pick (ClutterActor *self,
+    const ClutterColor *color)
+{
+  ChamplainTilePrivate *priv = GET_PRIVATE (self);
+
+  CLUTTER_ACTOR_CLASS (champlain_tile_parent_class)->pick (self, color);
+
+  clutter_actor_paint (CLUTTER_ACTOR (priv->content_group));
+}
+
+
+static void
+get_preferred_width (ClutterActor *self,
+    gfloat for_height,
+    gfloat *min_width_p,
+    gfloat *natural_width_p)
+{
+  ChamplainTilePrivate *priv = GET_PRIVATE (self);
+
+  clutter_actor_get_preferred_width (CLUTTER_ACTOR (priv->content_group),
+      for_height,
+      min_width_p,
+      natural_width_p);
+}
+
+
+static void
+get_preferred_height (ClutterActor *self,
+    gfloat for_width,
+    gfloat *min_height_p,
+    gfloat *natural_height_p)
+{
+  ChamplainTilePrivate *priv = GET_PRIVATE (self);
+
+  clutter_actor_get_preferred_height (CLUTTER_ACTOR (priv->content_group),
+      for_width,
+      min_height_p,
+      natural_height_p);
+}
+
+
+static void
+allocate (ClutterActor *self,
+    const ClutterActorBox *box,
+    ClutterAllocationFlags flags)
+{
+  ClutterActorBox child_box;
+
+  ChamplainTilePrivate *priv = GET_PRIVATE (self);
+
+  CLUTTER_ACTOR_CLASS (champlain_tile_parent_class)->allocate (self, box, flags);
+
+  child_box.x1 = 0;
+  child_box.x2 = box->x2 - box->x1;
+  child_box.y1 = 0;
+  child_box.y2 = box->y2 - box->y1;
+
+  clutter_actor_allocate (CLUTTER_ACTOR (priv->content_group), &child_box, flags);
+}
+
+
+static void
+map (ClutterActor *self)
+{
+  ChamplainTilePrivate *priv = GET_PRIVATE (self);
+
+  CLUTTER_ACTOR_CLASS (champlain_tile_parent_class)->map (self);
+
+  clutter_actor_map (CLUTTER_ACTOR (priv->content_group));
+}
+
+
+static void
+unmap (ClutterActor *self)
+{
+  ChamplainTilePrivate *priv = GET_PRIVATE (self);
+
+  CLUTTER_ACTOR_CLASS (champlain_tile_parent_class)->unmap (self);
+
+  clutter_actor_unmap (CLUTTER_ACTOR (priv->content_group));
+}
+
+
 static void
 champlain_tile_dispose (GObject *object)
 {
   ChamplainTilePrivate *priv = CHAMPLAIN_TILE (object)->priv;
 
-  if (priv->content_actor)
+  if (!priv->content_displayed && priv->content_actor)
     {
-      g_object_unref (priv->content_actor);
+      clutter_actor_destroy (priv->content_actor);
       priv->content_actor = NULL;
     }
+
   if (priv->content_group)
     {
       clutter_actor_unparent (CLUTTER_ACTOR (priv->content_group));
@@ -386,17 +463,23 @@ champlain_tile_class_init (ChamplainTileClass *klass)
    * @data: the result of the rendering
    * @size: size of data
    * @error: TRUE if there was an error during rendering
-   * 
+   *
    * The #ChamplainTile::render-complete signal is emitted when rendering of the tile is
    * completed by the renderer.
    *
    * Since: 0.10
    */
   champlain_tile_signals[RENDER_COMPLETE] =
-    g_signal_new ("render-complete", G_OBJECT_CLASS_TYPE (object_class),
-        G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-        _champlain_marshal_VOID__POINTER_UINT_BOOLEAN, G_TYPE_NONE,
-        3, G_TYPE_POINTER, G_TYPE_UINT, G_TYPE_BOOLEAN);
+    g_signal_new ("render-complete", 
+        G_OBJECT_CLASS_TYPE (object_class),
+        G_SIGNAL_RUN_LAST, 
+        0, 
+        NULL, 
+        NULL,
+        _champlain_marshal_VOID__POINTER_UINT_BOOLEAN, 
+        G_TYPE_NONE,
+        3, 
+        G_TYPE_POINTER, G_TYPE_UINT, G_TYPE_BOOLEAN);
 }
 
 
@@ -415,6 +498,7 @@ champlain_tile_init (ChamplainTile *self)
   priv->modified_time = NULL;
   priv->etag = NULL;
   priv->fade_in = FALSE;
+  priv->content_displayed = FALSE;
 
   priv->content_actor = NULL;
   priv->content_group = CLUTTER_GROUP (clutter_group_new ());
@@ -439,99 +523,6 @@ champlain_tile_new (void)
 }
 
 
-static void
-paint (ClutterActor *self)
-{
-  ChamplainTilePrivate *priv = GET_PRIVATE (self);
-  
-  clutter_actor_paint (CLUTTER_ACTOR (priv->content_group));
-}
-
-
-static void
-pick (ClutterActor *self, 
-    const ClutterColor *color)
-{
-  ChamplainTilePrivate *priv = GET_PRIVATE (self);
-
-  CLUTTER_ACTOR_CLASS (champlain_tile_parent_class)->pick (self, color);
-
-  clutter_actor_paint (CLUTTER_ACTOR (priv->content_group));
-}
-
-
-static void
-get_preferred_width (ClutterActor *self,
-    gfloat for_height,
-    gfloat *min_width_p,
-    gfloat *natural_width_p)
-{
-  ChamplainTilePrivate *priv = GET_PRIVATE (self);
-
-  clutter_actor_get_preferred_width (CLUTTER_ACTOR (priv->content_group),
-      for_height,
-      min_width_p,
-      natural_width_p);
-}
-
-
-static void
-get_preferred_height (ClutterActor *self,
-    gfloat for_width,
-    gfloat *min_height_p,
-    gfloat *natural_height_p)
-{
-  ChamplainTilePrivate *priv = GET_PRIVATE (self);
-
-  clutter_actor_get_preferred_height (CLUTTER_ACTOR (priv->content_group),
-      for_width,
-      min_height_p,
-      natural_height_p);
-}
-
-
-static void
-allocate (ClutterActor *self,
-    const ClutterActorBox *box,
-    ClutterAllocationFlags flags)
-{
-  ClutterActorBox child_box;
-
-  ChamplainTilePrivate *priv = GET_PRIVATE (self);
-
-  CLUTTER_ACTOR_CLASS (champlain_tile_parent_class)->allocate (self, box, flags);
-
-  child_box.x1 = 0;
-  child_box.x2 = box->x2 - box->x1;
-  child_box.y1 = 0;
-  child_box.y2 = box->y2 - box->y1;
-
-  clutter_actor_allocate (CLUTTER_ACTOR (priv->content_group), &child_box, flags);
-}
-
-
-static void
-map (ClutterActor *self)
-{
-  ChamplainTilePrivate *priv = GET_PRIVATE (self);
-
-  CLUTTER_ACTOR_CLASS (champlain_tile_parent_class)->map (self);
-
-  clutter_actor_map (CLUTTER_ACTOR (priv->content_group));
-}
-
-
-static void
-unmap (ClutterActor *self)
-{
-  ChamplainTilePrivate *priv = GET_PRIVATE (self);
-
-  CLUTTER_ACTOR_CLASS (champlain_tile_parent_class)->unmap (self);
-
-  clutter_actor_unmap (CLUTTER_ACTOR (priv->content_group));
-}
-
-
 /**
  * champlain_tile_get_x:
  * @self: the #ChamplainTile
@@ -755,8 +746,12 @@ champlain_tile_new_full (guint x,
     guint size,
     guint zoom_level)
 {
-  return g_object_new (CHAMPLAIN_TYPE_TILE, "x", x, "y", y, "zoom-level",
-      zoom_level, "size", size, NULL);
+  return g_object_new (CHAMPLAIN_TYPE_TILE, 
+      "x", x, 
+      "y", y, 
+      "zoom-level", zoom_level, 
+      "size", size, 
+      NULL);
 }
 
 
@@ -793,7 +788,7 @@ champlain_tile_set_modified_time (ChamplainTile *self,
     const GTimeVal *time_)
 {
   g_return_if_fail (CHAMPLAIN_TILE (self));
-  g_return_if_fail (time != NULL);
+  g_return_if_fail (time_ != NULL);
 
   ChamplainTilePrivate *priv = self->priv;
 
@@ -863,11 +858,12 @@ champlain_tile_set_content (ChamplainTile *self,
 
   ChamplainTilePrivate *priv = self->priv;
 
-  if (priv->content_actor)
+  if (!priv->content_displayed && priv->content_actor)
     clutter_actor_destroy (priv->content_actor);
 
   priv->content_actor = g_object_ref_sink (actor);
-
+  priv->content_displayed = FALSE;
+  
   g_object_notify (G_OBJECT (self), "content");
 }
 
@@ -898,34 +894,32 @@ champlain_tile_display_content (ChamplainTile *self)
   ChamplainTilePrivate *priv = self->priv;
   ClutterAnimation *animation;
 
-  if (!priv->content_actor)
+  if (!priv->content_actor || priv->content_displayed)
     return;
 
   clutter_container_add_actor (CLUTTER_CONTAINER (priv->content_group), priv->content_actor);
+  g_object_unref (priv->content_actor);
+  priv->content_displayed = TRUE;
 
-  clutter_actor_set_opacity (CLUTTER_ACTOR (self), 0);
-  clutter_actor_queue_relayout (CLUTTER_ACTOR (self));
+  clutter_actor_set_opacity (CLUTTER_ACTOR (priv->content_actor), 0);
   if (priv->fade_in)
     {
-      animation = clutter_actor_animate (CLUTTER_ACTOR (self),
-          CLUTTER_EASE_IN_CUBIC,
-          500,
-          "opacity", 255,
-          NULL);
+      animation = clutter_actor_animate (CLUTTER_ACTOR (priv->content_actor),
+            CLUTTER_EASE_IN_CUBIC,
+            500,
+            "opacity", 255,
+            NULL);
     }
   else
     {
-      animation = clutter_actor_animate (CLUTTER_ACTOR (self),
-          CLUTTER_LINEAR,
-          150,
-          "opacity", 255,
-          NULL);
+      animation = clutter_actor_animate (CLUTTER_ACTOR (priv->content_actor),
+            CLUTTER_LINEAR,
+            150,
+            "opacity", 255,
+            NULL);
     }
 
   g_signal_connect (animation, "completed", G_CALLBACK (fade_in_completed), self);
-
-  g_object_unref (priv->content_actor);
-  priv->content_actor = NULL;
 }
 
 
