@@ -42,7 +42,7 @@
  * an error occurs during download, an error tile will be displayed.
  *
  * The button-press-event and button-release-event signals are emitted each
- * time a mouse button is pressed on the @view.  
+ * time a mouse button is pressed on the @view.
  */
 
 #include "config.h"
@@ -67,12 +67,11 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <math.h>
-#include <mx-kinetic-scroll-view.h>
-#include <mx-viewport.h>
-#include <mx-adjustment.h>
-#include <mx-scrollable.h>
+#include <champlain-kinetic-scroll-view.h>
+#include <champlain-viewport.h>
+#include <champlain-adjustment.h>
 
-//#define VIEW_LOG 
+/* #define VIEW_LOG */
 #ifdef VIEW_LOG
 #define DEBUG_LOG() g_print ("%s\n", __FUNCTION__);
 #else
@@ -108,11 +107,12 @@ static guint signals[LAST_SIGNAL] = { 0, };
 
 #define GET_PRIVATE(obj) \
   (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CHAMPLAIN_TYPE_VIEW, ChamplainViewPrivate))
+  
 #define ZOOM_LEVEL_OUT_OF_RANGE(priv, level) \
   (level < priv->min_zoom_level || \
-   level > priv->max_zoom_level || \
+           level > priv->max_zoom_level || \
    level < champlain_map_source_get_min_zoom_level (priv->map_source) || \
-   level > champlain_map_source_get_max_zoom_level (priv->map_source))
+           level > champlain_map_source_get_max_zoom_level (priv->map_source))
 
 /* Between state values for go_to */
 typedef struct
@@ -136,6 +136,13 @@ typedef struct
 struct _ChamplainViewPrivate
 {
   ClutterActor *view_box;
+  ClutterActor *kinetic_scroll; /* Contains the viewport */
+  ClutterActor *viewport;  /* Contains the map_layer, license and markers */
+  ClutterActor *map_layer; /* Contains tiles actors (grouped by zoom level) */
+  ClutterActor *user_layers; /* Contains the markers */
+  ClutterActor *license_actor; /* Contains the license info */
+
+  ClutterLayoutManager *layout_manager;
 
   ChamplainMapSource *map_source; /* Current map tile source */
   gboolean kinetic_mode;
@@ -157,32 +164,20 @@ struct _ChamplainViewPrivate
   guint anchor_zoom_level; /* the zoom_level for which the current anchor has
                                 been computed for */
 
-  ClutterActor *kinetic_scroll; /* Contains the viewport */
-  ClutterActor *viewport;  /* Contains the map_layer, license and markers */
-  ClutterActor *map_layer; /* Contains tiles actors (grouped by zoom level) */
-  
   gint viewport_x;
   gint viewport_y;
   gint viewport_width;
   gint viewport_height;
-  
-  ClutterActor *viewport_container;
-
-  ClutterActor *user_layers; /* Contains the markers */
 
   gboolean keep_center_on_resize;
-
   gboolean zoom_on_double_click;
 
-  ClutterActor *license_actor; /* Contains the license info */
-
   ChamplainState state; /* View's global state */
 
   /* champlain_view_go_to's context, kept for stop_go_to */
   GoToContext *goto_context;
 
   gint tiles_loading;
-  ClutterLayoutManager *layout_manager;
 };
 
 G_DEFINE_TYPE (ChamplainView, champlain_view, CLUTTER_TYPE_ACTOR);
@@ -234,9 +229,9 @@ static gboolean fill_tile_cb (FillTileCallbackData *data);
 
 /* Updates the internals after the viewport changed */
 static void
-update_viewport (ChamplainView *view, 
-    gfloat x, 
-    gfloat y, 
+update_viewport (ChamplainView *view,
+    gfloat x,
+    gfloat y,
     gboolean force_relocate,
     gboolean set_coords)
 {
@@ -248,12 +243,12 @@ update_viewport (ChamplainView *view,
   if (set_coords)
     {
       priv->longitude = champlain_map_source_get_longitude (priv->map_source,
-          priv->zoom_level, 
-          x);
+            priv->zoom_level,
+            x);
 
       priv->latitude = champlain_map_source_get_latitude (priv->map_source,
-          priv->zoom_level,
-          y);
+            priv->zoom_level,
+            y);
     }
 
   relocate = view_update_anchor (view, x, y);
@@ -261,16 +256,15 @@ update_viewport (ChamplainView *view,
   priv->viewport_x = x - priv->anchor_x - priv->viewport_width / 2.0;
   priv->viewport_y = y - priv->anchor_y - priv->viewport_height / 2.0;
 
-  
+
   if (relocate || force_relocate)
     {
       g_signal_handlers_block_by_func (priv->viewport, G_CALLBACK (viewport_pos_changed_cb), view);
-      mx_viewport_set_origin (MX_VIEWPORT (priv->viewport),
+      champlain_viewport_set_origin (CHAMPLAIN_VIEWPORT (priv->viewport),
           priv->viewport_x,
-          priv->viewport_y,
-          0);
+          priv->viewport_y);
       g_signal_handlers_unblock_by_func (priv->viewport, G_CALLBACK (viewport_pos_changed_cb), view);
-      
+
       g_signal_emit_by_name (view, "layer-relocated", NULL);
     }
 
@@ -285,7 +279,7 @@ update_viewport (ChamplainView *view,
 
 
 static void
-panning_completed (G_GNUC_UNUSED MxKineticScrollView *scroll,
+panning_completed (G_GNUC_UNUSED ChamplainKineticScrollView *scroll,
     ChamplainView *view)
 {
   DEBUG_LOG ()
@@ -294,11 +288,11 @@ panning_completed (G_GNUC_UNUSED MxKineticScrollView *scroll,
   gfloat absolute_x, absolute_y;
   gfloat x, y;
 
-  mx_viewport_get_origin (MX_VIEWPORT (priv->viewport), &x, &y, NULL);
+  champlain_viewport_get_origin (CHAMPLAIN_VIEWPORT (priv->viewport), &x, &y);
 
   absolute_x = x + priv->anchor_x + priv->viewport_width / 2.0;
   absolute_y = y + priv->anchor_y + priv->viewport_height / 2.0;
-      
+
   update_viewport (view, absolute_x, absolute_y, FALSE, TRUE);
 }
 
@@ -332,11 +326,11 @@ resize_viewport (ChamplainView *view)
   gdouble lower_y = 0;
   gdouble upper_x = G_MAXINT16;
   gdouble upper_y = G_MAXINT16;
-  MxAdjustment *hadjust, *vadjust;
+  ChamplainAdjustment *hadjust, *vadjust;
 
   ChamplainViewPrivate *priv = view->priv;
 
-  mx_scrollable_get_adjustments (MX_SCROLLABLE (priv->viewport), &hadjust,
+  champlain_viewport_get_adjustments (CHAMPLAIN_VIEWPORT (priv->viewport), &hadjust,
       &vadjust);
 
   if (priv->zoom_level < 8)
@@ -353,17 +347,27 @@ resize_viewport (ChamplainView *view)
 
   /*
    * block emmision of signal by priv->viewport with viewport_pos_changed_cb()
-   * callback - the signal can be emitted by updating MxAdjustment, but
+   * callback - the signal can be emitted by updating ChamplainAdjustment, but
    * calling the callback now would be a disaster since we don't have updated
    * anchor yet
    */
   g_signal_handlers_block_by_func (priv->viewport, G_CALLBACK (viewport_pos_changed_cb), view);
 
-  g_object_set (hadjust, "lower", lower_x, "upper", upper_x,
-      "page-size", 1.0, "step-increment", 1.0, "elastic", TRUE, NULL);
+  g_object_set (hadjust, 
+      "lower", lower_x, 
+      "upper", upper_x,
+      "page-size", 1.0, 
+      "step-increment", 1.0, 
+      "elastic", TRUE, 
+      NULL);
 
-  g_object_set (vadjust, "lower", lower_y, "upper", upper_y,
-      "page-size", 1.0, "step-increment", 1.0, "elastic", TRUE, NULL);
+  g_object_set (vadjust, 
+      "lower", lower_y, 
+      "upper", upper_y,
+      "page-size", 1.0, 
+      "step-increment", 1.0, 
+      "elastic", TRUE, 
+      NULL);
 
   g_signal_handlers_unblock_by_func (priv->viewport, G_CALLBACK (viewport_pos_changed_cb), view);
 }
@@ -507,49 +511,6 @@ champlain_view_dispose (GObject *object)
   ChamplainView *view = CHAMPLAIN_VIEW (object);
   ChamplainViewPrivate *priv = view->priv;
 
-  if (priv->map_source != NULL)
-    {
-      g_object_unref (priv->map_source);
-      priv->map_source = NULL;
-    }
-
-  if (priv->view_box != NULL)
-    {
-      g_object_unref (priv->view_box);
-      priv->view_box = NULL;
-    }
-
-  if (priv->license_actor != NULL)
-    {
-      g_object_unref (priv->license_actor);
-      priv->license_actor = NULL;
-    }
-
-  if (priv->kinetic_scroll != NULL)
-    {
-      mx_kinetic_scroll_view_stop (MX_KINETIC_SCROLL_VIEW (priv->kinetic_scroll));
-      g_object_unref (priv->kinetic_scroll);
-      priv->kinetic_scroll = NULL;
-    }
-
-  if (priv->viewport != NULL)
-    {
-      g_object_unref (priv->viewport);
-      priv->viewport = NULL;
-    }
-
-  if (priv->map_layer != NULL)
-    {
-      g_object_unref (priv->map_layer);
-      priv->map_layer = NULL;
-    }
-
-  if (priv->user_layers != NULL)
-    {
-      g_object_unref (priv->user_layers);
-      priv->user_layers = NULL;
-    }
-
   if (priv->goto_context != NULL)
     champlain_view_stop_go_to (view);
 
@@ -559,6 +520,35 @@ champlain_view_dispose (GObject *object)
       priv->update_viewport_timer = NULL;
     }
 
+  if (priv->kinetic_scroll != NULL)
+    {
+      champlain_kinetic_scroll_view_stop (CHAMPLAIN_KINETIC_SCROLL_VIEW (priv->kinetic_scroll));
+      priv->kinetic_scroll = NULL;
+    }
+
+  if (priv->viewport != NULL)
+    {
+      champlain_viewport_stop (CHAMPLAIN_VIEWPORT (priv->viewport));
+      priv->viewport = NULL;
+    }
+
+  if (priv->map_source != NULL)
+    {
+      g_object_unref (priv->map_source);
+      priv->map_source = NULL;
+    }
+
+  if (priv->view_box != NULL)
+    {
+      clutter_actor_unparent (CLUTTER_ACTOR (priv->view_box));
+      priv->view_box = NULL;
+    }
+
+  priv->map_layer = NULL;
+  priv->license_actor = NULL;
+  priv->user_layers = NULL;
+  priv->layout_manager = NULL;
+
   G_OBJECT_CLASS (champlain_view_parent_class)->dispose (object);
 }
 
@@ -568,7 +558,7 @@ champlain_view_finalize (GObject *object)
 {
   DEBUG_LOG ()
 
-//  ChamplainViewPrivate *priv = CHAMPLAIN_VIEW (object)->priv;
+/*  ChamplainViewPrivate *priv = CHAMPLAIN_VIEW (object)->priv; */
 
   G_OBJECT_CLASS (champlain_view_parent_class)->finalize (object);
 }
@@ -610,13 +600,13 @@ champlain_view_allocate (ClutterActor *actor,
 
   /* Chain up */
   CLUTTER_ACTOR_CLASS (champlain_view_parent_class)->allocate (actor, box, flags);
-  
+
   width = box->x2 - box->x1;
   height = box->y2 - box->y1;
 
   if (priv->viewport_width != width || priv->viewport_height != height)
     {
-      g_idle_add_full (G_PRIORITY_HIGH_IDLE,
+      g_idle_add_full (CLUTTER_PRIORITY_REDRAW,
           (GSourceFunc) _update_idle_cb,
           g_object_ref (view),
           (GDestroyNotify) g_object_unref);
@@ -647,7 +637,7 @@ champlain_view_realize (ClutterActor *actor)
    * CLUTTER_ACTOR_CLASS (champlain_view_parent_class)->realize (actor);
    * ClutterStage uses clutter_actor_realize.
    */
-   
+
   clutter_actor_realize (actor);
 
   /* Setup the viewport according to the zoom level */
@@ -707,13 +697,13 @@ static void
 paint (ClutterActor *self)
 {
   ChamplainViewPrivate *priv = GET_PRIVATE (self);
-  
+
   clutter_actor_paint (CLUTTER_ACTOR (priv->view_box));
 }
 
 
 static void
-pick (ClutterActor *self, 
+pick (ClutterActor *self,
     const ClutterColor *color)
 {
   ChamplainViewPrivate *priv = GET_PRIVATE (self);
@@ -781,7 +771,10 @@ champlain_view_class_init (ChamplainViewClass *champlainViewClass)
       g_param_spec_double ("longitude",
           "Longitude",
           "The longitude coordonate of the map",
-          -180.0f, 180.0f, 0.0f, CHAMPLAIN_PARAM_READWRITE));
+          -180.0f, 
+          180.0f, 
+          0.0f, 
+          CHAMPLAIN_PARAM_READWRITE));
 
   /**
    * ChamplainView:latitude:
@@ -795,7 +788,10 @@ champlain_view_class_init (ChamplainViewClass *champlainViewClass)
       g_param_spec_double ("latitude",
           "Latitude",
           "The latitude coordonate of the map",
-          -90.0f, 90.0f, 0.0f, CHAMPLAIN_PARAM_READWRITE));
+          -90.0f, 
+          90.0f, 
+          0.0f, 
+          CHAMPLAIN_PARAM_READWRITE));
 
   /**
    * ChamplainView:zoom-level:
@@ -809,7 +805,10 @@ champlain_view_class_init (ChamplainViewClass *champlainViewClass)
       g_param_spec_uint ("zoom-level",
           "Zoom level",
           "The level of zoom of the map",
-          0, 20, 3, CHAMPLAIN_PARAM_READWRITE));
+          0, 
+          20, 
+          3, 
+          CHAMPLAIN_PARAM_READWRITE));
 
   /**
    * ChamplainView:min-zoom-level:
@@ -823,7 +822,10 @@ champlain_view_class_init (ChamplainViewClass *champlainViewClass)
       g_param_spec_uint ("min-zoom-level",
           "Min zoom level",
           "The lowest allowed level of zoom",
-          0, 20, 0, CHAMPLAIN_PARAM_READWRITE));
+          0, 
+          20, 
+          0, 
+          CHAMPLAIN_PARAM_READWRITE));
 
   /**
    * ChamplainView:max-zoom-level:
@@ -837,7 +839,10 @@ champlain_view_class_init (ChamplainViewClass *champlainViewClass)
       g_param_spec_uint ("max-zoom-level",
           "Max zoom level",
           "The highest allowed level of zoom",
-          0, 20, 20, CHAMPLAIN_PARAM_READWRITE));
+          0, 
+          20, 
+          20, 
+          CHAMPLAIN_PARAM_READWRITE));
 
   /**
    * ChamplainView:map-source:
@@ -866,7 +871,8 @@ champlain_view_class_init (ChamplainViewClass *champlainViewClass)
       g_param_spec_boolean ("kinetic-mode",
           "Kinetic Mode",
           "Determines whether the view should use kinetic mode.",
-          FALSE, CHAMPLAIN_PARAM_READWRITE));
+          FALSE, 
+          CHAMPLAIN_PARAM_READWRITE));
 
   /**
    * ChamplainView:deceleration:
@@ -880,7 +886,10 @@ champlain_view_class_init (ChamplainViewClass *champlainViewClass)
       g_param_spec_double ("deceleration",
           "Deceleration rate",
           "Rate at which the view will decelerate in kinetic mode.",
-          1.0001, 2.0, 1.1, CHAMPLAIN_PARAM_READWRITE));
+          1.0001, 
+          2.0, 
+          1.1, 
+          CHAMPLAIN_PARAM_READWRITE));
 
   /**
    * ChamplainView:keep-center-on-resize:
@@ -895,7 +904,8 @@ champlain_view_class_init (ChamplainViewClass *champlainViewClass)
           "Keep center on resize",
           "Keep the current centered position "
           "upon resizing",
-          TRUE, CHAMPLAIN_PARAM_READWRITE));
+          TRUE, 
+          CHAMPLAIN_PARAM_READWRITE));
 
   /**
    * ChamplainView:zoom-on-double-click:
@@ -909,7 +919,8 @@ champlain_view_class_init (ChamplainViewClass *champlainViewClass)
       g_param_spec_boolean ("zoom-on-double-click",
           "Zoom in on double click",
           "Zoom in and recenter on double click on the map",
-          TRUE, CHAMPLAIN_PARAM_READWRITE));
+          TRUE, 
+          CHAMPLAIN_PARAM_READWRITE));
 
   /**
    * ChamplainView:state
@@ -939,10 +950,14 @@ champlain_view_class_init (ChamplainViewClass *champlainViewClass)
    * Since: 0.4
    */
   signals[ANIMATION_COMPLETED] =
-    g_signal_new ("animation-completed", G_OBJECT_CLASS_TYPE (object_class),
-        G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED, 0, NULL, NULL,
-        g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 0);
-        
+    g_signal_new ("animation-completed", 
+        G_OBJECT_CLASS_TYPE (object_class),
+        G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED, 
+        0, NULL, NULL,
+        g_cclosure_marshal_VOID__OBJECT, 
+        G_TYPE_NONE, 
+        0);
+
   /**
    * ChamplainView::layer-relocated:
    *
@@ -954,10 +969,13 @@ champlain_view_class_init (ChamplainViewClass *champlainViewClass)
    * Since: 0.10
    */
   signals[LAYER_RELOCATED] =
-    g_signal_new ("layer-relocated", G_OBJECT_CLASS_TYPE (object_class),
-        G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-        g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
-        
+    g_signal_new ("layer-relocated", 
+        G_OBJECT_CLASS_TYPE (object_class),
+        G_SIGNAL_RUN_LAST, 
+        0, NULL, NULL,
+        g_cclosure_marshal_VOID__VOID, 
+        G_TYPE_NONE, 
+        0);
 }
 
 
@@ -969,6 +987,7 @@ champlain_view_init (ChamplainView *view)
   ChamplainViewPrivate *priv = GET_PRIVATE (view);
   ChamplainMapSourceFactory *factory;
   ChamplainMapSource *source;
+  ClutterActor *viewport_container;
 
   champlain_debug_set_flags (g_getenv ("CHAMPLAIN_DEBUG"));
 
@@ -999,29 +1018,29 @@ champlain_view_init (ChamplainView *view)
   priv->longitude = 0.0f;
   priv->goto_context = NULL;
   priv->tiles_loading = 0;
-  priv->update_viewport_timer = g_timer_new();
+  priv->update_viewport_timer = g_timer_new ();
 
   /* Setup map layer */
-  priv->map_layer = g_object_ref (champlain_group_new ());
+  priv->map_layer = champlain_group_new ();
   clutter_actor_show (priv->map_layer);
 
   /* Setup user_layers */
-  priv->user_layers = g_object_ref (clutter_group_new ());
+  priv->user_layers = clutter_group_new ();
   clutter_actor_show (priv->user_layers);
 
-  priv->viewport_container = g_object_ref (clutter_group_new ());
+  viewport_container = clutter_group_new ();
 
-  clutter_container_add_actor (CLUTTER_CONTAINER (priv->viewport_container),
+  clutter_container_add_actor (CLUTTER_CONTAINER (viewport_container),
       priv->map_layer);
-  clutter_container_add_actor (CLUTTER_CONTAINER (priv->viewport_container),
+  clutter_container_add_actor (CLUTTER_CONTAINER (viewport_container),
       priv->user_layers);
 
-  clutter_actor_show (priv->viewport_container);
+  clutter_actor_show (viewport_container);
 
   /* Setup viewport */
-  priv->viewport = g_object_ref (mx_viewport_new ());
-  mx_bin_set_child (MX_BIN (priv->viewport), priv->viewport_container);
-  
+  priv->viewport = champlain_viewport_new ();
+  champlain_viewport_set_child (CHAMPLAIN_VIEWPORT (priv->viewport), viewport_container);
+
   g_object_set (G_OBJECT (priv->viewport), "sync-adjustments", FALSE, NULL);
 
   g_signal_connect (priv->viewport, "notify::x-origin",
@@ -1032,7 +1051,7 @@ champlain_view_init (ChamplainView *view)
   clutter_actor_raise (priv->user_layers, priv->map_layer);
 
   /* Setup kinetic scroll */
-  priv->kinetic_scroll = g_object_ref (mx_kinetic_scroll_view_new ());
+  priv->kinetic_scroll = champlain_kinetic_scroll_view_new (FALSE);
 
   g_signal_connect (priv->kinetic_scroll, "scroll-event",
       G_CALLBACK (scroll_event), view);
@@ -1051,12 +1070,12 @@ champlain_view_init (ChamplainView *view)
 
   /* Setup stage */
   priv->layout_manager = clutter_bin_layout_new (CLUTTER_BIN_ALIGNMENT_CENTER,
-                                  CLUTTER_BIN_ALIGNMENT_CENTER);
-  priv->view_box = g_object_ref (clutter_box_new (priv->layout_manager));
+        CLUTTER_BIN_ALIGNMENT_CENTER);
+  priv->view_box = clutter_box_new (priv->layout_manager);
 
   clutter_bin_layout_add (CLUTTER_BIN_LAYOUT (priv->layout_manager), priv->kinetic_scroll,
-                          CLUTTER_BIN_ALIGNMENT_FILL,
-                          CLUTTER_BIN_ALIGNMENT_FILL);
+      CLUTTER_BIN_ALIGNMENT_FILL,
+      CLUTTER_BIN_ALIGNMENT_FILL);
 
   clutter_actor_set_parent (CLUTTER_ACTOR (priv->view_box), CLUTTER_ACTOR (view));
   clutter_actor_queue_relayout (CLUTTER_ACTOR (view));
@@ -1064,11 +1083,11 @@ champlain_view_init (ChamplainView *view)
   resize_viewport (view);
 
   /* Setup license */
-  priv->license_actor = g_object_ref (champlain_license_new ());
+  priv->license_actor = champlain_license_new ();
   champlain_license_connect_view (CHAMPLAIN_LICENSE (priv->license_actor), view);
   champlain_view_bin_layout_add (view, priv->license_actor,
-                                 CLUTTER_BIN_ALIGNMENT_END,
-                                 CLUTTER_BIN_ALIGNMENT_END);
+      CLUTTER_BIN_ALIGNMENT_END,
+      CLUTTER_BIN_ALIGNMENT_END);
 
   priv->state = CHAMPLAIN_STATE_DONE;
   g_object_notify (G_OBJECT (view), "state");
@@ -1085,19 +1104,19 @@ viewport_pos_changed_cb (G_GNUC_UNUSED GObject *gobject,
   ChamplainViewPrivate *priv = view->priv;
   gfloat x, y;
 
-  mx_viewport_get_origin (MX_VIEWPORT (priv->viewport), &x, &y, NULL);
+  champlain_viewport_get_origin (CHAMPLAIN_VIEWPORT (priv->viewport), &x, &y);
 
   if (fabs (x - priv->viewport_x) > 100 ||
       fabs (y - priv->viewport_y) > 100 ||
       g_timer_elapsed (priv->update_viewport_timer, NULL) > 0.25)
     {
       gdouble absolute_x, absolute_y;
-      
+
       absolute_x = x + priv->anchor_x + priv->viewport_width / 2.0;
       absolute_y = y + priv->anchor_y + priv->viewport_height / 2.0;
-      
+
       update_viewport (view, absolute_x, absolute_y, FALSE, TRUE);
-      
+
       g_timer_start (priv->update_viewport_timer);
     }
 }
@@ -1153,7 +1172,7 @@ scroll_to (ChamplainView *view,
 
   if (priv->kinetic_mode)
     champlain_view_go_to_with_duration (view, lat, lon, 300);
-  else 
+  else
     champlain_view_center_on (view, lat, lon);
 }
 
@@ -1337,7 +1356,7 @@ view_update_anchor (ChamplainView *view,
           priv->anchor_y = 0;
           DEBUG ("Clear Anchor at (%d, %d)", x, y);
         }
-    
+
       priv->anchor_zoom_level = priv->zoom_level;
     }
 
@@ -1624,6 +1643,7 @@ champlain_view_set_min_zoom_level (ChamplainView *view,
     return;
 
   priv->min_zoom_level = min_zoom_level;
+  g_object_notify (G_OBJECT (view), "min-zoom-level");
 
   if (priv->zoom_level < min_zoom_level)
     champlain_view_set_zoom_level (view, min_zoom_level);
@@ -1655,6 +1675,7 @@ champlain_view_set_max_zoom_level (ChamplainView *view,
     return;
 
   priv->max_zoom_level = max_zoom_level;
+  g_object_notify (G_OBJECT (view), "max-zoom-level");
 
   if (priv->zoom_level > max_zoom_level)
     champlain_view_set_zoom_level (view, max_zoom_level);
@@ -1678,12 +1699,11 @@ champlain_view_add_layer (ChamplainView *view,
 
   g_return_if_fail (CHAMPLAIN_IS_VIEW (view));
   g_return_if_fail (CHAMPLAIN_IS_LAYER (layer));
-  
+
   clutter_container_add_actor (CLUTTER_CONTAINER (view->priv->user_layers),
       CLUTTER_ACTOR (layer));
   champlain_layer_set_view (layer, view);
   clutter_actor_raise_top (CLUTTER_ACTOR (layer));
-  clutter_actor_queue_relayout (CLUTTER_ACTOR (view));
 }
 
 
@@ -1705,11 +1725,10 @@ champlain_view_remove_layer (ChamplainView *view,
   g_return_if_fail (CHAMPLAIN_IS_VIEW (view));
   g_return_if_fail (CHAMPLAIN_IS_LAYER (layer));
 
-  champlain_layer_set_view (layer, NULL);      
+  champlain_layer_set_view (layer, NULL);
 
   clutter_container_remove_actor (CLUTTER_CONTAINER (view->priv->user_layers),
       CLUTTER_ACTOR (layer));
-  clutter_actor_queue_relayout (CLUTTER_ACTOR (view));
 }
 
 
@@ -1721,7 +1740,7 @@ champlain_view_remove_layer (ChamplainView *view,
  * Converts the view's x coordinate to longitude.
  *
  * Returns: the longitude
- * 
+ *
  * Since: 0.10
  */
 gdouble
@@ -1733,11 +1752,11 @@ champlain_view_x_to_longitude (ChamplainView *view,
 
   DEBUG_LOG ()
 
-  g_return_val_if_fail (CHAMPLAIN_IS_VIEW (view), 0.0);  
-  
+  g_return_val_if_fail (CHAMPLAIN_IS_VIEW (view), 0.0);
+
   longitude = champlain_map_source_get_longitude (priv->map_source,
-      priv->zoom_level, 
-      x + priv->viewport_x + priv->anchor_x);
+        priv->zoom_level,
+        x + priv->viewport_x + priv->anchor_x);
 
   return longitude;
 }
@@ -1760,14 +1779,14 @@ champlain_view_y_to_latitude (ChamplainView *view,
 {
   ChamplainViewPrivate *priv = view->priv;
   gdouble latitude;
-  
+
   DEBUG_LOG ()
 
   g_return_val_if_fail (CHAMPLAIN_IS_VIEW (view), 0.0);
 
   latitude = champlain_map_source_get_latitude (priv->map_source,
-      priv->zoom_level, 
-      y + priv->viewport_y + priv->anchor_y);
+        priv->zoom_level,
+        y + priv->viewport_y + priv->anchor_y);
 
   return latitude;
 }
@@ -1785,12 +1804,12 @@ champlain_view_y_to_latitude (ChamplainView *view,
  * Since: 0.10
  */
 gdouble
-champlain_view_longitude_to_x (ChamplainView *view, 
+champlain_view_longitude_to_x (ChamplainView *view,
     gdouble longitude)
 {
   ChamplainViewPrivate *priv = view->priv;
   gdouble x;
-  
+
   DEBUG_LOG ()
 
   g_return_val_if_fail (CHAMPLAIN_IS_VIEW (view), 0);
@@ -1813,12 +1832,12 @@ champlain_view_longitude_to_x (ChamplainView *view,
  * Since: 0.10
  */
 gdouble
-champlain_view_latitude_to_y (ChamplainView *view, 
+champlain_view_latitude_to_y (ChamplainView *view,
     gdouble latitude)
 {
   ChamplainViewPrivate *priv = view->priv;
   gdouble y;
-  
+
   DEBUG_LOG ()
 
   g_return_val_if_fail (CHAMPLAIN_IS_VIEW (view), 0);
@@ -1839,19 +1858,19 @@ champlain_view_latitude_to_y (ChamplainView *view,
  *
  * Since: 0.10
  */
-void 
-champlain_view_get_viewport_origin (ChamplainView *view, 
-    gint *x, 
+void
+champlain_view_get_viewport_origin (ChamplainView *view,
+    gint *x,
     gint *y)
 {
   DEBUG_LOG ()
 
   g_return_if_fail (CHAMPLAIN_IS_VIEW (view));
   ChamplainViewPrivate *priv = view->priv;
-  
+
   if (x)
     *x = priv->viewport_x;
- 
+
   if (y)
     *y = priv->viewport_y;
 }
@@ -1924,7 +1943,7 @@ view_load_visible_tiles (ChamplainView *view)
           tile_y < y_first || tile_y >= y_end ||
           zoom_level != priv->zoom_level)
         {
-          // inform map source to terminate loading the tile
+          /* inform map source to terminate loading the tile */
           champlain_tile_set_state (tile, CHAMPLAIN_STATE_DONE);
           clutter_container_remove_actor (CLUTTER_CONTAINER (priv->map_layer), CLUTTER_ACTOR (tile));
         }
@@ -1955,9 +1974,11 @@ view_load_visible_tiles (ChamplainView *view)
 
               DEBUG ("Loading tile %d, %d, %d", priv->zoom_level, x, y);
               tile = champlain_tile_new ();
-              g_object_set (G_OBJECT (tile), "x", x, "y", y,
-                  "zoom-level", priv->zoom_level,
-                  "size", size, NULL);
+              champlain_tile_set_x (tile, x);
+              champlain_tile_set_y (tile, y);
+              champlain_tile_set_zoom_level (tile, priv->zoom_level);
+              champlain_tile_set_size (tile, size);
+                  
               g_signal_connect (tile, "notify::state", G_CALLBACK (tile_state_notify), view);
               clutter_container_add_actor (CLUTTER_CONTAINER (priv->map_layer), CLUTTER_ACTOR (tile));
               view_position_tile (view, tile);
@@ -1973,8 +1994,7 @@ view_load_visible_tiles (ChamplainView *view)
               g_object_ref (tile);
               g_object_ref (priv->map_source);
 
-              /* set priority high, otherwise tiles will be loaded after panning is done */
-              g_idle_add_full (G_PRIORITY_HIGH_IDLE, (GSourceFunc) fill_tile_cb, data, NULL);
+              g_idle_add_full (CLUTTER_PRIORITY_REDRAW, (GSourceFunc) fill_tile_cb, data, NULL);
             }
 
           x += dirs[turn % 4 + 1];
@@ -2046,8 +2066,8 @@ remove_all_tiles (ChamplainView *view)
       ChamplainTile *tile = CHAMPLAIN_TILE (child->data);
 
       champlain_tile_set_state (tile, CHAMPLAIN_STATE_DONE);
-      clutter_container_remove_actor (CLUTTER_CONTAINER (priv->map_layer), CLUTTER_ACTOR (tile));
     }
+  champlain_group_remove_all (CHAMPLAIN_GROUP (priv->map_layer));
   g_list_free (children);
 }
 
@@ -2099,7 +2119,6 @@ tile_state_notify (ChamplainTile *tile,
           priv->state = CHAMPLAIN_STATE_DONE;
           g_object_notify (G_OBJECT (view), "state");
         }
-    
     }
 }
 
@@ -2173,6 +2192,7 @@ champlain_view_set_deceleration (ChamplainView *view,
       rate < 2.0 && rate > 1.0001);
 
   g_object_set (view->priv->kinetic_scroll, "deceleration", rate, NULL);
+  g_object_notify (G_OBJECT (view), "deceleration");
 }
 
 
@@ -2196,7 +2216,8 @@ champlain_view_set_kinetic_mode (ChamplainView *view,
   ChamplainViewPrivate *priv = view->priv;
 
   priv->kinetic_mode = kinetic;
-  mx_kinetic_scroll_view_set_kinetic_mode (MX_KINETIC_SCROLL_VIEW (priv->kinetic_scroll), kinetic);
+  g_object_set (view->priv->kinetic_scroll, "mode", kinetic, NULL);
+  g_object_notify (G_OBJECT (view), "kinetic-mode");
 }
 
 
@@ -2218,6 +2239,7 @@ champlain_view_set_keep_center_on_resize (ChamplainView *view,
   g_return_if_fail (CHAMPLAIN_IS_VIEW (view));
 
   view->priv->keep_center_on_resize = value;
+  g_object_notify (G_OBJECT (view), "keep-center-on-resize");
 }
 
 
@@ -2239,6 +2261,7 @@ champlain_view_set_zoom_on_double_click (ChamplainView *view,
   g_return_if_fail (CHAMPLAIN_IS_VIEW (view));
 
   view->priv->zoom_on_double_click = value;
+  g_object_notify (G_OBJECT (view), "zoom-on-double-click");
 }
 
 
@@ -2264,7 +2287,7 @@ champlain_view_ensure_visible (ChamplainView *view,
   guint zoom_level = priv->zoom_level;
   gboolean good_size = FALSE;
   gdouble lat, lon;
-  
+
   if (!champlain_bounding_box_is_valid (bbox))
     return;
 
@@ -2274,7 +2297,7 @@ champlain_view_ensure_visible (ChamplainView *view,
   do
     {
       gint min_x, min_y, max_x, max_y;
-      
+
       min_x = champlain_map_source_get_x (priv->map_source, zoom_level, bbox->left);
       min_y = champlain_map_source_get_y (priv->map_source, zoom_level, bbox->bottom);
       max_x = champlain_map_source_get_x (priv->map_source, zoom_level, bbox->right);
@@ -2320,11 +2343,11 @@ champlain_view_ensure_layers_visible (ChamplainView *view,
 
   GList *layers, *elem;
   ChamplainBoundingBox *bbox;
-  
+
   bbox = champlain_bounding_box_new ();
-  
+
   layers = clutter_container_get_children (CLUTTER_CONTAINER (view->priv->user_layers));
-  
+
   for (elem = layers; elem != NULL; elem = elem->next)
     {
       ChamplainLayer *layer = CHAMPLAIN_LAYER (elem->data);
@@ -2366,11 +2389,11 @@ view_set_zoom_level_at (ChamplainView *view,
 
   /* Keep the lon, lat where the mouse is */
   lon = champlain_map_source_get_longitude (priv->map_source,
-    priv->zoom_level, 
-    priv->viewport_x + x + priv->anchor_x);
+        priv->zoom_level,
+        priv->viewport_x + x + priv->anchor_x);
   lat = champlain_map_source_get_latitude (priv->map_source,
-      priv->zoom_level,
-      priv->viewport_y + y + priv->anchor_y);
+        priv->zoom_level,
+        priv->viewport_y + y + priv->anchor_y);
 
   /* How far was it from the center of the viewport (in px) */
   x_diff = priv->viewport_width / 2 - x;
@@ -2384,9 +2407,9 @@ view_set_zoom_level_at (ChamplainView *view,
   /* Get the new lon,lat of these new x,y minus the distance from the
    * viewport center */
   lon2 = champlain_map_source_get_longitude (priv->map_source,
-    priv->zoom_level, x2 + x_diff);
+        priv->zoom_level, x2 + x_diff);
   lat2 = champlain_map_source_get_latitude (priv->map_source,
-    priv->zoom_level, y2 + y_diff);
+        priv->zoom_level, y2 + y_diff);
 
   resize_viewport (view);
   champlain_view_center_on (view, lat2, lon2);
@@ -2580,10 +2603,11 @@ champlain_view_get_zoom_on_double_click (ChamplainView *view)
  *
  * Since: 0.10
  */
-void champlain_view_bin_layout_add (ChamplainView *view,
-  ClutterActor *child,
-  ClutterBinAlignment x_align,
-  ClutterBinAlignment y_align)
+void
+champlain_view_bin_layout_add (ChamplainView *view,
+    ClutterActor *child,
+    ClutterBinAlignment x_align,
+    ClutterBinAlignment y_align)
 {
   ChamplainViewPrivate *priv = view->priv;
   ClutterBinLayout *layout_manager;
@@ -2591,14 +2615,13 @@ void champlain_view_bin_layout_add (ChamplainView *view,
   DEBUG_LOG ()
 
   g_return_if_fail (CHAMPLAIN_IS_VIEW (view));
-  
+
   layout_manager = CLUTTER_BIN_LAYOUT (priv->layout_manager);
   clutter_bin_layout_add (layout_manager, child, x_align, y_align);
   clutter_actor_queue_relayout (CLUTTER_ACTOR (view));
 }
 
 
-
 /**
  * champlain_view_get_license_actor:
  * @view: The view
@@ -2611,11 +2634,75 @@ void champlain_view_bin_layout_add (ChamplainView *view,
  *
  * Since: 0.10
  */
-ChamplainLicense *champlain_view_get_license_actor (ChamplainView *view)
+ChamplainLicense *
+champlain_view_get_license_actor (ChamplainView *view)
 {
   DEBUG_LOG ()
 
   g_return_val_if_fail (CHAMPLAIN_IS_VIEW (view), NULL);
-  
-  return CHAMPLAIN_LICENSE (view->priv->license_actor);      
+
+  return CHAMPLAIN_LICENSE (view->priv->license_actor);
+}
+
+
+/**
+ * champlain_view_get_center_latitude:
+ * @view: The view
+ *
+ * Gets the latitude of the view's center.
+ *
+ * Returns: the latitude.
+ *
+ * Since: 0.10
+ */
+gdouble
+champlain_view_get_center_latitude (ChamplainView *view)
+{
+  DEBUG_LOG ()
+
+  g_return_val_if_fail (CHAMPLAIN_IS_VIEW (view), 0.0);
+
+  return view->priv->latitude;
+}
+
+
+/**
+ * champlain_view_get_center_longitude:
+ * @view: The view
+ *
+ * Gets the longitude of the view's center.
+ *
+ * Returns: the latitude.
+ *
+ * Since: 0.10
+ */
+gdouble
+champlain_view_get_center_longitude (ChamplainView *view)
+{
+  DEBUG_LOG ()
+
+  g_return_val_if_fail (CHAMPLAIN_IS_VIEW (view), 0.0);
+
+  return view->priv->longitude;
+}
+
+
+/**
+ * champlain_view_get_state:
+ * @view: The view
+ *
+ * Gets the view's state.
+ *
+ * Returns: the state.
+ *
+ * Since: 0.10
+ */
+ChamplainState
+champlain_view_get_state (ChamplainView *view)
+{
+  DEBUG_LOG ()
+
+  g_return_val_if_fail (CHAMPLAIN_IS_VIEW (view), CHAMPLAIN_STATE_NONE);
+
+  return view->priv->state;
 }
